pub enum Area {
Rect(Rect),
StartingAt {
x: isize,
y: isize,
},
BlockStartingAt {
bo: BlockOffset,
},
}Variants
Rect(Rect)
A well-defined rectangle
StartingAt
A rectangle starting at offset (x, y) and ending at the bottom-right corner of the parent
BlockStartingAt
a rectangle starting at given block offset until the bottom-right corner of the parent
Fields

bo: BlockOffsetImplementations
Sourceimpl Area
impl Area
Sourcepub const fn to_rect(
self,
xdec: usize,
ydec: usize,
parent_width: usize,
parent_height: usize,
) -> Rect
pub const fn to_rect( self, xdec: usize, ydec: usize, parent_width: usize, parent_height: usize, ) -> Rect
Convert to a rectangle of pixels.
For a BlockRect and BlockStartingAt, for subsampled chroma planes,
the returned rect will be aligned to a 4x4 chroma block.
This is necessary for compute_distortion and rdo_cfl_alpha as
the subsampled chroma block covers multiple luma blocks.