PlaneRegion

Struct PlaneRegion 

pub struct PlaneRegion<'a, T: Pixel> {
    data: *const T,
    pub plane_cfg: &'a PlaneConfig,
    rect: Rect,
    phantom: PhantomData<&'a T>,
}
Bounded region of a plane

This allows giving access to a rectangular area of a plane without giving access to the whole plane.

Fields

data: *const Tplane_cfg: &'a PlaneConfigrect: Rectphantom: PhantomData<&'a T>

Implementations

Source

impl<'a, T: Pixel> PlaneRegion<'a, T>

pub fn empty(plane_cfg: &'a PlaneConfig) -> Self

pub fn from_slice(data: &'a [T], cfg: &'a PlaneConfig, rect: Rect) -> Self

Panics
  • If the configured dimensions are invalid
unsafe fn from_slice_unsafe( data: &'a [T], cfg: &'a PlaneConfig, rect: Rect, ) -> Self

pub fn new(plane: &'a Plane<T>, rect: Rect) -> Self

pub fn new_from_plane(plane: &'a Plane<T>) -> Self

pub fn data_ptr(&self) -> *const T

pub fn rect(&self) -> &Rect

pub fn rows_iter(&self) -> PlaneRegionRowsIter<'_, T>

pub fn vert_windows(&self, h: usize) -> VertWindows<'_, T>

pub fn horz_windows(&self, w: usize) -> HorzWindows<'_, T>

pub fn subregion(&self, area: Area) -> PlaneRegion<'_, T>

Return a view to a subregion of the plane

The subregion must be included in (i.e. must not exceed) this region.

It is described by an Area, relative to this region.

Panics
  • If the requested dimensions are larger than the plane region size
Example
// a subregion from (10, 8) to the end of the region
let subregion = region.subregion(Area::StartingAt { x: 10, y: 8 });
// a subregion from the top-left of block (2, 3) having size (64, 64)
let bo = BlockOffset { x: 2, y: 3 };
let subregion = region.subregion(Area::BlockRect { bo, width: 64, height: 64 });